summaryrefslogtreecommitdiff
path: root/pkgs/development/libraries/igraph/default.nix
diff options
context:
space:
mode:
authorRobin Gloster <mail@glob.in>2021-05-24 09:55:24 -0500
committerRobin Gloster <mail@glob.in>2021-05-24 09:55:24 -0500
commit4bc5fbef9d159e143fb7e2c3231932e6e76f667c (patch)
treee2198f5c552e0667d838b8ec764ddb3a4d8f6dec /pkgs/development/libraries/igraph/default.nix
parentjq: fix build with structured-attrs on darwin (diff)
parentMerge pull request #123802 from superherointj/package-virtmanager-bugfix (diff)
downloadnixpkgs-origin/structured-attrs.tar.gz
Merge remote-tracking branch 'upstream/master' into structured-attrsorigin/structured-attrs
Diffstat (limited to 'pkgs/development/libraries/igraph/default.nix')
-rw-r--r--pkgs/development/libraries/igraph/default.nix12
1 files changed, 7 insertions, 5 deletions
diff --git a/pkgs/development/libraries/igraph/default.nix b/pkgs/development/libraries/igraph/default.nix
index 86b8b7130ff4..29e12cc8541d 100644
--- a/pkgs/development/libraries/igraph/default.nix
+++ b/pkgs/development/libraries/igraph/default.nix
@@ -21,13 +21,13 @@
stdenv.mkDerivation rec {
pname = "igraph";
- version = "0.9.2";
+ version = "0.9.3";
src = fetchFromGitHub {
owner = "igraph";
repo = pname;
rev = version;
- sha256 = "sha256-Ylw02Mz9H4wIWfq59za/X7xfhgW9o0DNU55nLFqeUeo=";
+ sha256 = "sha256-StRXtP2PelPcS+l5O1AOVFkza3hiKFwCdp8XLal4grE=";
};
# Normally, igraph wants us to call bootstrap.sh, which will call
@@ -77,15 +77,17 @@ stdenv.mkDerivation rec {
"-DIGRAPH_USE_INTERNAL_GMP=OFF"
"-DIGRAPH_GLPK_SUPPORT=ON"
"-DIGRAPH_GRAPHML_SUPPORT=ON"
- "-DIGRAPH_ENABLE_LTO=ON"
+ "-DIGRAPH_ENABLE_LTO=AUTO"
"-DIGRAPH_ENABLE_TLS=ON"
"-DBUILD_SHARED_LIBS=ON"
];
doCheck = true;
- preCheck = ''
- # needed to find libigraph.so
+ # needed to find libigraph, and liblas on darwin
+ preCheck = if stdenv.isDarwin then ''
+ export DYLD_LIBRARY_PATH="${lib.makeLibraryPath [ blas ]}:$PWD/src"
+ '' else ''
export LD_LIBRARY_PATH="$PWD/src"
'';